@@ -6,9 +6,31 @@ use 5.008001;
 use Acme::Alien::DontPanic ();
 use FFI::Platypus::Declare;
 
+# ABSTRACT: FFI test module for Alien::Base
+our $VERSION = '1.9800'; # VERSION
+
+
+our($dll) = Acme::Alien::DontPanic->dynamic_libs;
+die "no dll found for libdontpanic" unless $dll;
+lib $dll;
+
+attach answer => [] => int => '';
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Acme::Ford::Prefect - FFI test module for Alien::Base
+Acme::Ford::Prefect::FFI - FFI test module for Alien::Base
+
+=head1 VERSION
+
+version 1.9800
 
 =head1 SYNOPSIS
 
@@ -22,7 +44,15 @@ L<Alien::Base> comprises base classes to help in the construction of C<Alien::>
 external libraries needed by other Perl modules.
 
 This module is a toy module to test the efficacy of the L<Alien::Base> system with its experimental FFI interfaces.  This module depends on another toy module 
-L<Acme::Alien::DontPanic> which provides the needed libdontpanic library to be able to tell us the C<answer> to life, the universe and everythin.
+L<Acme::Alien::DontPanic> which provides the needed libdontpanic library to be able to tell us the C<answer> to life, the universe and everything.
+
+=head1 FUNCTIONS
+
+=head2 answer
+
+ my $answer = Acme::Ford::Prefect::answer();
+
+Returns the answer to life the universe and everything.  Not exported.
 
 =head1 SEE ALSO
 
@@ -36,22 +66,15 @@ L<Acme::Alien::DontPanic> which provides the needed libdontpanic library to be a
 
 =back
 
+=head1 AUTHOR
+
+Graham Ollis <plicease@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013 Graham Ollis
+This software is copyright (c) 2014-2020 by Graham Ollis.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-our $VERSION = '1.96';
-
-our($dll) = Acme::Alien::DontPanic->dynamic_libs;
-die "no dll found for libdontpanic" unless $dll;
-lib $dll;
-
-attach answer => [] => int => '';
-
-1;
-
